@@ -9,7 +9,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <https://computing.llnl.gov/linux/slurm/>.
+ *  For details, see <http://www.schedmd.com/slurmdocs/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -121,7 +121,7 @@ enum {
 	ESLURM_ERROR_ON_DESC_TO_RECORD_COPY,
 	ESLURM_JOB_MISSING_SIZE_SPECIFICATION,
 	ESLURM_JOB_SCRIPT_MISSING,
-	ESLURM_USER_ID_MISSING,
+	ESLURM_USER_ID_MISSING =			2010,
 	ESLURM_DUPLICATE_JOB_ID,
 	ESLURM_PATHNAME_TOO_LONG,
 	ESLURM_NOT_TOP_PRIORITY,
@@ -131,7 +131,7 @@ enum {
 	ESLURM_INVALID_JOB_ID,
 	ESLURM_INVALID_NODE_NAME,
 	ESLURM_WRITING_TO_FILE,
-	ESLURM_TRANSITION_STATE_NO_UPDATE,
+	ESLURM_TRANSITION_STATE_NO_UPDATE =		2020,
 	ESLURM_ALREADY_DONE,
 	ESLURM_INTERCONNECT_FAILURE,
 	ESLURM_BAD_DIST,
@@ -141,7 +141,7 @@ enum {
 	ESLURM_IN_STANDBY_MODE,
 	ESLURM_INVALID_NODE_STATE,
 	ESLURM_INVALID_FEATURE,
-	ESLURM_INVALID_AUTHTYPE_CHANGE,
+	ESLURM_INVALID_AUTHTYPE_CHANGE =		2030,
 	ESLURM_INVALID_CHECKPOINT_TYPE_CHANGE,
 	ESLURM_INVALID_SCHEDTYPE_CHANGE,
 	ESLURM_INVALID_SELECTTYPE_CHANGE,
@@ -151,7 +151,7 @@ enum {
 	ESLURM_DISABLED,
 	ESLURM_DEPENDENCY,
 	ESLURM_BATCH_ONLY,
-	ESLURM_TASKDIST_ARBITRARY_UNSUPPORTED,
+	ESLURM_TASKDIST_ARBITRARY_UNSUPPORTED =		2040,
 	ESLURM_TASKDIST_REQUIRES_OVERCOMMIT,
 	ESLURM_JOB_HELD,
 	ESLURM_INVALID_CRYPTO_TYPE_CHANGE,
@@ -161,7 +161,7 @@ enum {
 	ESLURM_SAME_PARENT_ACCOUNT,
 	ESLURM_INVALID_LICENSES,
 	ESLURM_NEED_RESTART,
-	ESLURM_ACCOUNTING_POLICY,
+	ESLURM_ACCOUNTING_POLICY =			2050,
 	ESLURM_INVALID_TIME_LIMIT,
 	ESLURM_RESERVATION_ACCESS,
 	ESLURM_RESERVATION_INVALID,
@@ -171,7 +171,7 @@ enum {
 	ESLURM_INVALID_WCKEY,
 	ESLURM_RESERVATION_OVERLAP,
 	ESLURM_PORTS_BUSY,
-	ESLURM_PORTS_INVALID,
+	ESLURM_PORTS_INVALID =				2060,
 	ESLURM_PROLOG_RUNNING,
 	ESLURM_NO_STEPS,
 	ESLURM_INVALID_BLOCK_STATE,
@@ -181,11 +181,14 @@ enum {
 	ESLURM_QOS_PREEMPTION_LOOP,
 	ESLURM_NODE_NOT_AVAIL,
 	ESLURM_INVALID_CPU_COUNT,
-	ESLURM_PARTITION_NOT_AVAIL,
+	ESLURM_PARTITION_NOT_AVAIL =			2070,
 	ESLURM_CIRCULAR_DEPENDENCY,
 	ESLURM_INVALID_GRES,
 	ESLURM_JOB_NOT_PENDING,
 	ESLURM_QOS_THRES,
+	ESLURM_PARTITION_IN_USE,
+	ESLURM_STEP_LIMIT,
+	ESLURM_JOB_SUSPENDED,
 
 	/* switch specific error codes, specific values defined in plugin module */
 	ESLURM_SWITCH_MIN = 3000,
