@@ -9,7 +9,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <https://computing.llnl.gov/linux/slurm/>.
+ *  For details, see <http://www.schedmd.com/slurmdocs/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -55,7 +55,7 @@
 #include <arpa/inet.h>
 #include <unistd.h>
 
-#include <slurm/slurm.h>
+#include "slurm/slurm.h"
 
 #include "src/common/parse_time.h"
 #include "src/common/slurm_protocol_api.h"
@@ -131,7 +131,7 @@ slurm_sprint_node_table (node_info_t * node_ptr,
 	int total_used = node_ptr->cpus;
 	uint32_t cluster_flags = slurmdb_setup_cluster_flags();
 
-	if(node_scaling)
+	if (node_scaling)
 		cpus_per_node = node_ptr->cpus / node_scaling;
 
 	if (my_state & NODE_STATE_COMPLETING) {
@@ -150,10 +150,10 @@ slurm_sprint_node_table (node_info_t * node_ptr,
 				  SELECT_NODEDATA_SUBCNT,
 				  NODE_STATE_ALLOCATED,
 				  &alloc_cpus);
-	if(cluster_flags & CLUSTER_FLAG_BG) {
-		if(!alloc_cpus
-		   && (IS_NODE_ALLOCATED(node_ptr)
-		       || IS_NODE_COMPLETING(node_ptr)))
+	if (cluster_flags & CLUSTER_FLAG_BG) {
+		if (!alloc_cpus &&
+		    (IS_NODE_ALLOCATED(node_ptr) ||
+		     IS_NODE_COMPLETING(node_ptr)))
 			alloc_cpus = node_ptr->cpus;
 		else
 			alloc_cpus *= cpus_per_node;
@@ -164,7 +164,7 @@ slurm_sprint_node_table (node_info_t * node_ptr,
 				  SELECT_NODEDATA_SUBCNT,
 				  NODE_STATE_ERROR,
 				  &err_cpus);
-	if(cluster_flags & CLUSTER_FLAG_BG)
+	if (cluster_flags & CLUSTER_FLAG_BG)
 		err_cpus *= cpus_per_node;
 	total_used -= err_cpus;
 
@@ -177,7 +177,7 @@ slurm_sprint_node_table (node_info_t * node_ptr,
 	/****** Line 1 ******/
 	snprintf(tmp_line, sizeof(tmp_line), "NodeName=%s ", node_ptr->name);
 	xstrcat(out, tmp_line);
-	if (node_ptr->arch ) {
+	if (node_ptr->arch) {
 		snprintf(tmp_line, sizeof(tmp_line), "Arch=%s ",
 			 node_ptr->arch);
 		xstrcat(out, tmp_line);
@@ -208,7 +208,19 @@ slurm_sprint_node_table (node_info_t * node_ptr,
 	else
 		xstrcat(out, "\n   ");
 
-	/****** Line 4 ******/
+	/****** Line 4 (optional) ******/
+	if (node_ptr->node_hostname || node_ptr->node_addr) {
+		snprintf(tmp_line, sizeof(tmp_line),
+			 "NodeAddr=%s NodeHostName=%s",
+			 node_ptr->node_addr, node_ptr->node_hostname);
+		xstrcat(out, tmp_line);	
+		if (one_liner)
+			xstrcat(out, " ");
+		else
+			xstrcat(out, "\n   ");
+	}
+
+	/****** Line 5 ******/
 	if (node_ptr->os) {
 		snprintf(tmp_line, sizeof(tmp_line), "OS=%s ", node_ptr->os);
 		xstrcat(out, tmp_line);
@@ -221,7 +233,7 @@ slurm_sprint_node_table (node_info_t * node_ptr,
 	else
 		xstrcat(out, "\n   ");
 
-	/****** Line 5 ******/
+	/****** Line 6 ******/
 
 	snprintf(tmp_line, sizeof(tmp_line),
 		 "State=%s%s%s%s ThreadsPerCore=%u TmpDisk=%u Weight=%u",
@@ -233,7 +245,7 @@ slurm_sprint_node_table (node_info_t * node_ptr,
 	else
 		xstrcat(out, "\n   ");
 
-	/****** Line 6 ******/
+	/****** Line 7 ******/
 	if (node_ptr->boot_time) {
 		slurm_make_time_str ((time_t *)&node_ptr->boot_time,
 				     time_str, sizeof(time_str));
@@ -256,7 +268,7 @@ slurm_sprint_node_table (node_info_t * node_ptr,
 	else
 		xstrcat(out, "\n   ");
 
-	/****** Line 7 ******/
+	/****** Line 8 ******/
 	if (node_ptr->reason_time) {
 		char *user_name = uid_to_string(node_ptr->reason_uid);
 		slurm_make_time_str ((time_t *)&node_ptr->reason_time,
