@@ -8,7 +8,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <https://computing.llnl.gov/linux/slurm/>.
+ *  For details, see <http://www.schedmd.com/slurmdocs/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -92,8 +92,8 @@ static bool _listening_socket_readable(eio_obj_t *obj);
 static int _listening_socket_read(eio_obj_t *obj, List objs);
 
 struct io_operations listening_socket_ops = {
-	readable:	&_listening_socket_readable,
-	handle_read:	&_listening_socket_read
+	.readable = &_listening_socket_readable,
+	.handle_read = &_listening_socket_read
 };
 
 /**********************************************************************
@@ -105,10 +105,10 @@ static bool _server_writable(eio_obj_t *obj);
 static int _server_write(eio_obj_t *obj, List objs);
 
 struct io_operations server_ops = {
-        readable:	&_server_readable,
-	handle_read:	&_server_read,
-	writable:       &_server_writable,
-	handle_write:   &_server_write
+	.readable = &_server_readable,
+	.handle_read = &_server_read,
+	.writable = &_server_writable,
+	.handle_write = &_server_write
 };
 
 struct server_io_info {
@@ -138,8 +138,8 @@ static bool _file_writable(eio_obj_t *obj);
 static int _file_write(eio_obj_t *obj, List objs);
 
 struct io_operations file_write_ops = {
-	writable:	&_file_writable,
-	handle_write:	&_file_write,
+	.writable = &_file_writable,
+	.handle_write = &_file_write,
 };
 
 struct file_write_info {
@@ -163,8 +163,8 @@ static bool _file_readable(eio_obj_t *obj);
 static int _file_read(eio_obj_t *obj, List objs);
 
 struct io_operations file_read_ops = {
-	readable:	&_file_readable,
-	handle_read:	&_file_read,
+	.readable = &_file_readable,
+	.handle_read = &_file_read,
 };
 
 struct file_read_info {
@@ -1071,7 +1071,6 @@ client_io_handler_create(slurm_step_io_fds_t fds,
 			 bool label)
 {
 	client_io_t *cio;
-	int len;
 	int i;
 	uint32_t siglen;
 	char *sig;
@@ -1089,8 +1088,6 @@ client_io_handler_create(slurm_step_io_fds_t fds,
 	else
 		cio->label_width = 0;
 
-	len = sizeof(uint32_t) * num_tasks;
-
 	if (slurm_cred_get_signature(cred, &sig, &siglen) < 0) {
 		error("client_io_handler_create, invalid credential");
 		return NULL;
