@@ -7,7 +7,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <https://computing.llnl.gov/linux/slurm/>.
+ *  For details, see <http://www.schedmd.com/slurmdocs/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -39,7 +39,7 @@
 #ifndef _GRES_H
 #define _GRES_H
 
-#include <slurm/slurm.h>
+#include "slurm/slurm.h"
 #include "src/common/bitstring.h"
 #include "src/common/pack.h"
 
@@ -91,7 +91,7 @@ typedef struct gres_node_state {
 
 /* Gres job state as used by slurmctld daemon */
 typedef struct gres_job_state {
-	/* Count of resources needed */
+	/* Count of resources needed per node */
 	uint32_t gres_cnt_alloc;
 
 	/* Resources currently allocated to job on each node */
@@ -107,7 +107,7 @@ typedef struct gres_job_state {
 
 /* Gres job step state as used by slurmctld daemon */
 typedef struct gres_step_state {
-	/* Count of resources needed */
+	/* Count of resources needed per node */
 	uint32_t gres_cnt_alloc;
 
 	/* Resources currently allocated to the job step on each node
@@ -171,6 +171,35 @@ extern int gres_plugin_node_config_load(uint32_t cpu_cnt);
  */
 extern int gres_plugin_node_config_pack(Buf buffer);
 
+/*
+ * Return information about the configured gres devices on the node
+ * OUT dev_path - the devices paths as written on gres.conf file
+ * OUT gres_name - the names of the devices (ex. gpu, nic,..)
+ * IN array_len - count of elements in dev_path and gres_name
+ * OUT int - number of lines of gres.conf file
+ */
+extern int gres_plugin_node_config_devices_path(char **dev_path,
+						char **gres_name,
+						int array_len);
+
+/*
+ * Provide information about the allocate gres devices for a particular job
+ * IN gres_list - jobs allocated gres devices
+ * IN gres_count - count of gres.conf records for each gres name
+ * OUT gres_bit_alloc - the exact devices which are allocated
+ */
+extern void gres_plugin_job_state_file(List gres_list, int *gres_bit_alloc,
+				       int *gres_count);
+
+/*
+ * Provide information about the allocate gres devices for a particular step
+ * IN gres_list - jobs allocated gres devices
+ * IN gres_count - count of gres.conf records for each gres name
+ * OUT gres_bit_alloc - the exact devices which are allocated
+ */
+extern void gres_plugin_step_state_file(List gres_list, int *gres_bit_alloc,
+					int *gres_count);
+
 /*
  **************************************************************************
  *                 PLUGIN CALLS FOR SLURMCTLD DAEMON                      *
@@ -370,6 +399,21 @@ extern int gres_plugin_job_dealloc(List job_gres_list, List node_gres_list,
 				   int node_offset, uint32_t job_id,
 				   char *node_name);
 
+/*
+ * Merge one job's gres allocation into another job's gres allocation.
+ * IN from_job_gres_list - List of gres records for the job being merged
+ *			into another job
+ * IN from_job_node_bitmap - bitmap of nodes for the job being merged into
+ *			another job
+ * IN/OUT to_job_gres_list - List of gres records for the job being merged
+ *			into job
+ * IN to_job_node_bitmap - bitmap of nodes for the job being merged into
+ */
+extern void gres_plugin_job_merge(List from_job_gres_list,
+				  bitstr_t *from_job_node_bitmap,
+				  List to_job_gres_list,
+				  bitstr_t *to_job_node_bitmap);
+
 /*
  * Set environment variables as required for a batch job
  * IN/OUT job_env_ptr - environment variable array
@@ -377,6 +421,18 @@ extern int gres_plugin_job_dealloc(List job_gres_list, List node_gres_list,
   */
 extern void gres_plugin_job_set_env(char ***job_env_ptr, List job_gres_list);
 
+
+/*
+ * Extract from the job record's gres_list the count of allocated resources of
+ * 	the named gres gres typee.
+ * IN job_gres_list  - job record's gres_list.
+ * IN gres_name_type - the name of the gres type to retrieve the associated
+ *	value from.
+ * RET The value associated with the gres type or NO_VAL if not found.
+ */
+extern uint32_t gres_plugin_get_job_value_by_type(List job_gres_list,
+						  char *gres_name_type);
+
 /*
  * Log a job's current gres state
  * IN gres_list - generated by gres_plugin_job_state_validate()
@@ -412,6 +468,16 @@ List gres_plugin_step_state_dup(List gres_list);
  */
 List gres_plugin_step_state_extract(List gres_list, int node_index);
 
+/*
+ * A job allocation size has changed. Update the job step gres information
+ * bitmaps and other data structures.
+ * IN gres_list - List of Gres records for this step to track usage
+ * IN orig_job_node_bitmap - bitmap of nodes in the original job allocation
+ * IN new_job_node_bitmap - bitmap of nodes in the new job allocation
+ */
+void gres_plugin_step_state_rebase(List gres_list,
+				   bitstr_t *orig_job_node_bitmap,
+				   bitstr_t *new_job_node_bitmap);
 
 /*
  * Pack a step's current gres status, called from slurmctld for save/restore
@@ -486,5 +552,4 @@ extern int gres_plugin_step_alloc(List step_gres_list, List job_gres_list,
  */
 extern int gres_plugin_step_dealloc(List step_gres_list, List job_gres_list,
 				    uint32_t job_id, uint32_t step_id);
-
 #endif /* !_GRES_H */
