@@ -7,7 +7,7 @@
  *  from existing SLURM source code, particularly src/srun/opt.c
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <https://computing.llnl.gov/linux/slurm/>.
+ *  For details, see <http://www.schedmd.com/slurmdocs/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -141,7 +141,7 @@ task_dist_states_t verify_dist_type(const char *arg, uint32_t *plane_size)
 		} else if (strncasecmp(arg, "block", len) == 0) {
 			result = SLURM_DIST_BLOCK;
 		} else if ((strncasecmp(arg, "arbitrary", len) == 0) ||
-		           (strncasecmp(arg, "hostfile", len) == 0)) {
+			   (strncasecmp(arg, "hostfile", len) == 0)) {
 			result = SLURM_DIST_ARBITRARY;
 		}
 	}
@@ -149,25 +149,10 @@ task_dist_states_t verify_dist_type(const char *arg, uint32_t *plane_size)
 	return result;
 }
 
-/*
- * verify that a connection type in arg is of known form
- * returns the connection_type or -1 if not recognized
- */
-uint16_t verify_conn_type(const char *arg)
+static uint16_t _get_conn_type(char *arg, bool bgp)
 {
 	uint16_t len = strlen(arg);
-	bool no_bgl = 1;
-
-	if(working_cluster_rec) {
-		if(working_cluster_rec->flags & CLUSTER_FLAG_BGL)
-			no_bgl = 0;
-	} else {
-#ifdef HAVE_BGL
-		no_bgl = 0;
-#endif
-	}
-
-	if(!len) {
+	if (!len) {
 		/* no input given */
 		error("no conn-type argument given.");
 		return (uint16_t)NO_VAL;
@@ -177,9 +162,11 @@ uint16_t verify_conn_type(const char *arg)
 		return SELECT_TORUS;
 	else if (!strncasecmp(arg, "NAV", len))
 		return SELECT_NAV;
-	else if (no_bgl) {
-		if(!strncasecmp(arg, "HTC", len)
-		   || !strncasecmp(arg, "HTC_S", len))
+	else if (!strncasecmp(arg, "SMALL", len))
+		return SELECT_SMALL;
+	else if (bgp) {
+		if (!strncasecmp(arg, "HTC", len) ||
+		    !strncasecmp(arg, "HTC_S", len))
 			return SELECT_HTC_S;
 		else if (!strncasecmp(arg, "HTC_D", len))
 			return SELECT_HTC_D;
@@ -188,10 +175,56 @@ uint16_t verify_conn_type(const char *arg)
 		else if (!strncasecmp(arg, "HTC_L", len))
 			return SELECT_HTC_L;
 	}
+
 	error("invalid conn-type argument '%s' ignored.", arg);
 	return (uint16_t)NO_VAL;
 }
 
+/*
+ * verify comma separated list of connection types to array of uint16_t
+ * connection_types or NO_VAL if not recognized
+ */
+extern void verify_conn_type(const char *arg, uint16_t *conn_type)
+{
+	bool got_bgp = 0;
+	int inx = 0;
+	int highest_dims = 1;
+	char *arg_tmp = xstrdup(arg), *tok, *save_ptr = NULL;
+
+	if (working_cluster_rec) {
+		if (working_cluster_rec->flags & CLUSTER_FLAG_BGP)
+			got_bgp = 1;
+		else if (working_cluster_rec->flags & CLUSTER_FLAG_BGQ)
+			highest_dims = 4;
+	} else {
+#ifdef HAVE_BGP
+		got_bgp = 1;
+# elif defined HAVE_BGQ
+		highest_dims = 4;
+#endif
+	}
+
+	tok = strtok_r(arg_tmp, ",", &save_ptr);
+	while (tok) {
+		if (inx >= highest_dims) {
+			error("too many conn-type arguments: %s", arg);
+			break;
+		}
+		conn_type[inx++] = _get_conn_type(tok, got_bgp);
+		tok = strtok_r(NULL, ",", &save_ptr);
+	}
+	if (inx == 0)
+		error("invalid conn-type argument '%s' ignored.", arg);
+	/* Fill the rest in with NO_VALS (use HIGHEST_DIMS here
+	 * instead of highest_dims since that is the size of the
+	 * array. */
+	for ( ; inx < HIGHEST_DIMENSIONS; inx++) {
+		conn_type[inx] = (uint16_t)NO_VAL;
+	}
+
+	xfree(arg_tmp);
+}
+
 /*
  * verify geometry arguments, must have proper count
  * returns -1 on error, 0 otherwise
@@ -297,6 +330,10 @@ _str_to_nodes(const char *num_str, char **leftover)
 		num *= 1024;
 		endptr++;
 	}
+	if (*endptr != '\0' && (*endptr == 'm' || *endptr == 'M')) {
+		num *= (1024 * 1024);
+		endptr++;
+	}
 	*leftover = endptr;
 
 	return (int)num;
@@ -378,7 +415,7 @@ bool verify_node_list(char **node_list_pptr, enum task_dist_states dist,
 	   saying, lay it out this way! */
 	if(dist == SLURM_DIST_ARBITRARY)
 		nodelist = slurm_read_hostfile(*node_list_pptr, task_count);
-        else
+	else
 		nodelist = slurm_read_hostfile(*node_list_pptr, NO_VAL);
 
 	if (!nodelist)
@@ -417,7 +454,7 @@ bool get_resource_arg_range(const char *arg, const char *what, int* min,
 	}
 
 	result = strtol(arg, &p, 10);
-        if (*p == 'k' || *p == 'K') {
+	if (*p == 'k' || *p == 'K') {
 		result *= 1024;
 		p++;
 	} else if(*p == 'm' || *p == 'M') {
@@ -445,7 +482,7 @@ bool get_resource_arg_range(const char *arg, const char *what, int* min,
 		p++;
 
 	result = strtol(p, &p, 10);
-        if ((*p == 'k') || (*p == 'K')) {
+	if ((*p == 'k') || (*p == 'K')) {
 		result *= 1024;
 		p++;
 	} else if(*p == 'm' || *p == 'M') {
@@ -514,7 +551,7 @@ bool verify_socket_core_thread_count(const char *arg, int *min_sockets,
 		} else if (j == 2) {
 			*cpu_bind_type |= CPU_BIND_TO_THREADS;
 		}
-        }
+	}
 	buf[j][i] = '\0';
 
 	ret_val = true;
@@ -544,7 +581,7 @@ bool verify_socket_core_thread_count(const char *arg, int *min_sockets,
  * RET true if valid
  */
 bool verify_hint(const char *arg, int *min_sockets, int *min_cores,
-		 int *min_threads, int *ntasks_per_core, 
+		 int *min_threads, int *ntasks_per_core,
 		 cpu_bind_type_t *cpu_bind_type)
 {
 	char *buf, *p, *tok;
@@ -557,7 +594,7 @@ bool verify_hint(const char *arg, int *min_sockets, int *min_cores,
 	/* change all ',' delimiters not followed by a digit to ';'  */
 	/* simplifies parsing tokens while keeping map/mask together */
 	while (p[0] != '\0') {
-		if ((p[0] == ',') && (!isdigit(p[1])))
+		if ((p[0] == ',') && (!isdigit((int)p[1])))
 			p[0] = ';';
 		p++;
 	}
@@ -574,21 +611,21 @@ bool verify_hint(const char *arg, int *min_sockets, int *min_cores,
 "        help            show this help message\n");
 			return 1;
 		} else if (strcasecmp(tok, "compute_bound") == 0) {
-		        *min_sockets = NO_VAL;
-		        *min_cores   = NO_VAL;
-		        *min_threads = 1;
+			*min_sockets = NO_VAL;
+			*min_cores   = NO_VAL;
+			*min_threads = 1;
 			*cpu_bind_type |= CPU_BIND_TO_CORES;
 		} else if (strcasecmp(tok, "memory_bound") == 0) {
-		        *min_cores   = 1;
-		        *min_threads = 1;
+			*min_cores   = 1;
+			*min_threads = 1;
 			*cpu_bind_type |= CPU_BIND_TO_CORES;
 		} else if (strcasecmp(tok, "multithread") == 0) {
-		        *min_threads = NO_VAL;
+			*min_threads = NO_VAL;
 			*cpu_bind_type |= CPU_BIND_TO_THREADS;
 			if (*ntasks_per_core == NO_VAL)
 				*ntasks_per_core = INFINITE;
 		} else if (strcasecmp(tok, "nomultithread") == 0) {
-		        *min_threads = 1;
+			*min_threads = 1;
 			*cpu_bind_type |= CPU_BIND_TO_THREADS;
 		} else {
 			error("unrecognized --hint argument \"%s\", "
@@ -615,7 +652,7 @@ uint16_t parse_mail_type(const char *arg)
 	else if (strcasecmp(arg, "REQUEUE") == 0)
 		rc = MAIL_JOB_REQUEUE;
 	else if (strcasecmp(arg, "ALL") == 0)
-		rc = MAIL_JOB_BEGIN |  MAIL_JOB_END |  MAIL_JOB_FAIL | 
+		rc = MAIL_JOB_BEGIN |  MAIL_JOB_END |  MAIL_JOB_FAIL |
 		     MAIL_JOB_REQUEUE;
 	else
 		rc = 0;		/* failure */
@@ -690,7 +727,7 @@ search_path(char *cwd, char *cmd, bool check_current_dir, int access_mode)
 	char *path, *fullpath = NULL;
 
 	if (  (cmd[0] == '.' || cmd[0] == '/')
-           && (access(cmd, access_mode) == 0 ) ) {
+	   && (access(cmd, access_mode) == 0 ) ) {
 		if (cmd[0] == '.')
 			xstrfmtcat(fullpath, "%s/", cwd);
 		xstrcat(fullpath, cmd);
@@ -813,7 +850,7 @@ int sig_name2num(char *signal_name)
 			return 0;
 	} else {
 		ptr = (char *)signal_name;
-		while (isspace(*ptr))
+		while (isspace((int)*ptr))
 			ptr++;
 		if (strncasecmp(ptr, "SIG", 3) == 0)
 			ptr += 3;
@@ -823,7 +860,7 @@ int sig_name2num(char *signal_name)
 			if (strncasecmp(ptr, sig_name[i],
 					strlen(sig_name[i])) == 0) {
 				/* found the signal name */
-				if (!xstring_is_whitespace(ptr + 
+				if (!xstring_is_whitespace(ptr +
 							   strlen(sig_name[i])))
 					return 0;
 				sig = sig_num[i];
