@@ -584,9 +584,11 @@ extern List as_mysql_modify_job(mysql_conn_t *mysql_conn, uint32_t uid,
 	if (job->derived_ec != NO_VAL)
 		xstrfmtcat(vals, ", derived_ec=%u", job->derived_ec);
 
-	if (job->derived_es)
-		xstrfmtcat(vals, ", derived_es='%s'", job->derived_es);
-
+	if (job->derived_es) {
+		char *derived_es = slurm_add_slash_to_quotes(job->derived_es);
+		xstrfmtcat(vals, ", derived_es='%s'", derived_es);
+		xfree(derived_es);
+	}
 	if (!vals) {
 		errno = SLURM_NO_CHANGE_IN_DATA;
 		error("No change specified for job modification");
@@ -713,15 +715,23 @@ extern int as_mysql_job_complete(mysql_conn_t *mysql_conn,
 				    submit_time,
 				    job_ptr->job_id,
 				    job_ptr->assoc_id))) {
+			/* Comment is overloaded in job_start to be
+			   the block_id, so we will need to store this
+			   for later.
+			*/
+			char *comment = job_ptr->comment;
+			job_ptr->comment = NULL;
 			/* If we get an error with this just fall
 			 * through to avoid an infinite loop
 			 */
 			if (as_mysql_job_start(
 				    mysql_conn, job_ptr) == SLURM_ERROR) {
+				job_ptr->comment = comment;
 				error("couldn't add job %u at job completion",
 				      job_ptr->job_id);
 				return SLURM_SUCCESS;
 			}
+			job_ptr->comment = comment;
 		}
 	}
 
