@@ -9,7 +9,7 @@
  *  Written by Danny Auble <da@llnl.gov>
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <https://computing.llnl.gov/linux/slurm/>.
+ *  For details, see <http://www.schedmd.com/slurmdocs/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -595,6 +595,19 @@ extern int clusteracct_storage_p_register_ctld(pgsql_conn_t *pg_conn,
 	return cs_pg_register_ctld(pg_conn, pg_conn->cluster_name, port);
 }
 
+extern int clusteracct_storage_p_register_disconn_ctld(
+	pgsql_conn_t *pg_conn, char *control_host)
+{
+	return SLURM_SUCCESS;
+}
+
+extern int clusteracct_storage_p_fini_ctld(void *db_conn,
+					   char *ip, uint16_t port,
+					   char *cluster_nodes)
+{
+	return SLURM_SUCCESS;
+}
+
 extern int clusteracct_storage_p_cluster_cpus(pgsql_conn_t *pg_conn,
 					      char *cluster_nodes,
 					      uint32_t cpus,
