@@ -58,8 +58,9 @@
 #include <libgen.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <slurm/slurm.h>
-#include <slurm/slurm_errno.h>
+
+#include "slurm/slurm.h"
+#include "slurm/slurm_errno.h"
 
 #include "src/common/list.h"
 #include "src/common/log.h"
