@@ -6,7 +6,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <https://computing.llnl.gov/linux/slurm/>.
+ *  For details, see <http://www.schedmd.com/slurmdocs/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -52,14 +52,15 @@
 #include <signal.h>
 #include <stdlib.h>
 #include <unistd.h>
-#include <slurm/slurm.h>
-#include <slurm/slurm_errno.h>
+
+#include "slurm/slurm.h"
+#include "slurm/slurm_errno.h"
 #include "src/common/log.h"
 #include "src/slurmd/common/proctrack.h"
 
 const char plugin_name[] = "Process tracking for QsNet via the rms module";
 const char plugin_type[]      = "proctrack/rms";
-const uint32_t plugin_version = 1;
+const uint32_t plugin_version = 91;
 
 static int _prg_destructor_fork(void);
 static void _prg_destructor_send(int fd, int prgid);
@@ -81,14 +82,14 @@ extern int fini (void)
 
 /*
  * When proctrack/rms is used in conjunction with switch/elan,
- * slurm_container_create will not normally create the program description.
- * It just retrieves the prgid created in switch/elan.
+ * slurm_container_plugin_create will not normally create the program
+ * description.  It just retrieves the prgid created in switch/elan.
  *
  * When the program description cannot be retrieved (switch/elan is not
  * being used, the job step is a batch script, etc.) then rms_prgcreate()
  * is called here.
  */
-extern int slurm_container_create (slurmd_job_t *job)
+extern int slurm_container_plugin_create (slurmd_job_t *job)
 {
 	int prgid;
 	/*
@@ -107,21 +108,21 @@ extern int slurm_container_create (slurmd_job_t *job)
 	}
         debug3("proctrack/rms: prgid = %d", prgid);
 
-	job->cont_id = (uint32_t)prgid;
+	job->cont_id = (uint64_t)prgid;
 	return SLURM_SUCCESS;
 }
 
-extern int slurm_container_add (slurmd_job_t *job, pid_t pid)
+extern int slurm_container_plugin_add (slurmd_job_t *job, pid_t pid)
 {
 	return SLURM_SUCCESS;
 }
 
 /*
- * slurm_container_signal assumes that the slurmd jobstep manager
+ * slurm_container_plugin_signal assumes that the slurmd jobstep manager
  * is always the last process in the rms program description.
  * No signals are sent to the last process.
  */
-extern int slurm_container_signal  (uint32_t id, int signal)
+extern int slurm_container_plugin_signal  (uint64_t id, int signal)
 {
 	pid_t *pids;
 	int nids = 0;
@@ -165,42 +166,42 @@ extern int slurm_container_signal  (uint32_t id, int signal)
  * returns SLURM_SUCCESS when the program description contains one and
  * only one process, assumed to be the slurmd jobstep manager.
  */
-extern int slurm_container_destroy (uint32_t id)
+extern int slurm_container_plugin_destroy (uint64_t id)
 {
-	debug2("proctrack/rms: destroying container %u", id);
+	debug2("proctrack/rms: destroying container %"PRIu64"", id);
 	if (id == 0)
 		return SLURM_SUCCESS;
 
-	if (slurm_container_signal(id, 0) == -1)
+	if (slurm_container_plugin_signal(id, 0) == -1)
 		return SLURM_SUCCESS;
 
 	return SLURM_ERROR;
 }
 
 
-extern uint32_t slurm_container_find (pid_t pid)
+extern uint64_t slurm_container_plugin_find (pid_t pid)
 {
 	int prgid = 0;
 
 	if (rms_getprgid ((int) pid, &prgid) < 0)
-		return (uint32_t) 0;
-	return (uint32_t) prgid;
+		return (uint64_t) 0;
+	return (uint64_t) prgid;
 }
 
-extern bool slurm_container_has_pid (uint32_t cont_id, pid_t pid)
+extern bool slurm_container_plugin_has_pid (uint64_t cont_id, pid_t pid)
 {
 	int prgid = 0;
 
 	if (rms_getprgid ((int) pid, &prgid) < 0)
 		return false;
-	if ((uint32_t)prgid != cont_id)
+	if ((uint64_t)prgid != cont_id)
 		return false;
 
 	return true;
 }
 
 extern int
-slurm_container_wait(uint32_t cont_id)
+slurm_container_plugin_wait(uint64_t cont_id)
 {
 	int delay = 1;
 
@@ -210,13 +211,13 @@ slurm_container_wait(uint32_t cont_id)
 	}
 
 	/* Spin until the container is empty */
-	while (slurm_container_signal(cont_id, 0) != -1) {
-		slurm_container_signal(cont_id, SIGKILL);
+	while (slurm_container_plugin_signal(cont_id, 0) != -1) {
+		slurm_container_plugin_signal(cont_id, SIGKILL);
 		sleep(delay);
 		if (delay < 120) {
 			delay *= 2;
 		} else {
-			error("Unable to destroy container %u", cont_id);
+			error("Unable to destroy container %"PRIu64"", cont_id);
 		}
 	}
 
@@ -229,7 +230,7 @@ slurm_container_wait(uint32_t cont_id)
  * the slurmstepd in the list of pids that we return.
  */
 extern int
-slurm_container_get_pids(uint32_t cont_id, pid_t **pids, int *npids)
+slurm_container_plugin_get_pids(uint64_t cont_id, pid_t **pids, int *npids)
 {
 	pid_t *p;
 	int np;
@@ -280,7 +281,7 @@ _close_all_fd_except(int fd)
  * parent process has exited.  Then call rms_prgdestroy.
  */
 static int
-_prg_destructor_fork()
+_prg_destructor_fork(void)
 {
 	pid_t pid;
 	int fdpair[2];
