@@ -10,7 +10,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <https://computing.llnl.gov/linux/slurm/>.
+ *  For details, see <http://www.schedmd.com/slurmdocs/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -434,3 +434,11 @@ extern int task_post_term (slurmd_job_t *job)
 	return SLURM_SUCCESS;
 }
 
+/*
+ * task_post_step() is called after termination of the step
+ * (all the task)
+ */
+extern int task_post_step (slurmd_job_t *job)
+{
+	return SLURM_SUCCESS;
+}
