@@ -1,13 +1,13 @@
 /*****************************************************************************\
  *  licenses.c - Functions for handling cluster-wide consumable resources
  *****************************************************************************
- *  Copyright (C) 2008-2010 Lawrence Livermore National Security.
+ *  Copyright (C) 2008-2011 Lawrence Livermore National Security.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Morris Jette <jette@llnl.gov>, et. al.
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <https://computing.llnl.gov/linux/slurm/>.
+ *  For details, see <http://www.schedmd.com/slurmdocs/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -39,10 +39,11 @@
 #include <ctype.h>
 #include <errno.h>
 #include <pthread.h>
-#include <slurm/slurm_errno.h>
 #include <stdlib.h>
 #include <string.h>
 
+#include "slurm/slurm_errno.h"
+
 #include "src/common/list.h"
 #include "src/common/log.h"
 #include "src/common/macros.h"
@@ -121,25 +122,32 @@ static List _build_license_list(char *licenses, bool *valid)
 	tmp_str = xstrdup(licenses);
 	token = strtok_r(tmp_str, ",;", &last);
 	while (token && *valid) {
-		uint16_t num = 1;
-		for (i=0; token[i]; i++) {
+		uint32_t num = 1;
+		for (i = 0; token[i]; i++) {
 			if (isspace(token[i])) {
 				*valid = false;
 				break;
 			}
 			if (token[i] == '*') {
 				token[i++] = '\0';
-				num = (uint16_t)strtol(&token[i], &end_num,10);
+				num = (uint32_t)strtol(&token[i], &end_num,10);
 			}
 		}
 		if (num <= 0) {
 			*valid = false;
 			break;
 		}
-		license_entry = xmalloc(sizeof(licenses_t));
-		license_entry->name = xstrdup(token);
-		license_entry->total = num;
-		list_push(lic_list, license_entry);
+
+		license_entry = list_find_first(lic_list, _license_find_rec,
+						token);
+		if (license_entry) {
+			license_entry->total += num;
+		} else {
+			license_entry = xmalloc(sizeof(licenses_t));
+			license_entry->name = xstrdup(token);
+			license_entry->total = num;
+			list_push(lic_list, license_entry);
+		}
 		token = strtok_r(NULL, ",;", &last);
 	}
 	xfree(tmp_str);
@@ -151,6 +159,36 @@ static List _build_license_list(char *licenses, bool *valid)
 	return lic_list;
 }
 
+/* Given a list of license_t records, return a license string.
+ * This can be combined with _build_license_list() to eliminate duplicates
+ * (e.g. "tux*2,tux*3" gets changed to "tux*5"). */
+static char * _build_license_string(List license_list)
+{
+	char buf[128], *sep;
+	char *licenses = NULL;
+	ListIterator iter;
+	licenses_t *license_entry;
+
+	if (!license_list)
+		return licenses;
+
+	iter = list_iterator_create(license_list);
+	if (iter == NULL)
+		fatal("malloc failure from list_iterator_create");
+	while ((license_entry = (licenses_t *) list_next(iter))) {
+		if (licenses)
+			sep = ",";
+		else
+			sep = "";
+		snprintf(buf, sizeof(buf), "%s%s*%u", sep, license_entry->name,
+			 license_entry->total);
+		xstrcat(licenses, buf);
+	}
+	list_iterator_destroy(iter);
+
+	return licenses;
+}
+
 /* Initialize licenses on this system based upon slurm.conf */
 extern int license_init(char *licenses)
 {
@@ -262,7 +300,7 @@ extern List license_validate(char *licenses, bool *valid)
 			break;
 		} else if (license_entry->total > match->total) {
 			debug("job wants more %s licenses than configured",
-			     match->name);
+			      match->name);
 			*valid = false;
 			break;
 		}
@@ -277,6 +315,22 @@ extern List license_validate(char *licenses, bool *valid)
 	return job_license_list;
 }
 
+/*
+ * license_job_merge - The licenses from one job have just been merged into
+ *	another job by appending one job's licenses to another, possibly
+ *	including duplicate names. Reconstruct this job's licenses and
+ *	license_list fields to eliminate duplicates.
+ */
+extern void license_job_merge(struct job_record *job_ptr)
+{
+	bool valid;
+
+	FREE_NULL_LIST(job_ptr->license_list);
+	job_ptr->license_list = _build_license_list(job_ptr->licenses, &valid);
+	xfree(job_ptr->licenses);
+	job_ptr->licenses = _build_license_string(job_ptr->license_list);
+}
+
 /*
  * license_job_test - Test if the licenses required for a job are available
  * IN job_ptr - job identification
