@@ -47,5 +47,5 @@
  * "task_rank" is the task's GLOBAL rank within the job step.
  */
 extern int multi_prog_get_argv(char *config_data, char **prog_env,
-			       int task_rank, int *argc, char ***argv);
+			       int task_rank, uint32_t *argc, char ***argv);
 #endif /* !_SLURMD_MULTI_PROG_H */
