@@ -83,7 +83,6 @@
 #include "src/common/xmalloc.h"
 
 #include "src/slurmd/slurmd/slurmd.h"
-#include "src/slurmd/slurmstepd/io.h"
 #include "src/slurmd/slurmstepd/pdebug.h"
 #include "src/slurmd/slurmstepd/task.h"
 #include "src/slurmd/slurmstepd/ulimits.h"
@@ -392,8 +391,6 @@ exec_task(slurmd_job_t *job, int i)
 		}
 	}
 
-	io_dup_stdio(task);
-
 	/* task-specific pre-launch activities */
 
 	if (spank_user_task (job, i) < 0) {
