@@ -3,14 +3,14 @@
  *  mode of smap.
  *****************************************************************************
  *  Copyright (C) 2004-2007 The Regents of the University of California.
- *  Copyright (C) 2008-2010 Lawrence Livermore National Security.
+ *  Copyright (C) 2008-2011 Lawrence Livermore National Security.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Danny Auble <da@llnl.gov>
  *
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <https://computing.llnl.gov/linux/slurm/>.
+ *  For details, see <http://www.schedmd.com/slurmdocs/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -42,43 +42,42 @@
 #include "src/smap/smap.h"
 #include "src/common/node_select.h"
 #include "src/common/parse_time.h"
-#include "src/plugins/select/bluegene/plugin/bluegene.h"
 
 #define _DEBUG 0
 
 typedef struct {
 	char *bg_block_name;
-	enum connection_type bg_conn_type;
-	enum node_use_type bg_node_use;
+	uint16_t bg_conn_type[HIGHEST_DIMENSIONS];
+	uint16_t bg_node_use;
 	char *bg_user_name;
-	char *ionodes;
+	char *ionode_str;
 	int job_running;
 	int letter_num;
 	List nodelist;
-	char *nodes;
-	int node_cnt;
+	char *mp_str;
+	int cnode_cnt;
 	bool printed;
 	int size;
 	char *slurm_part_name;
-	rm_partition_state_t state;
+	uint16_t state;
 } db2_block_info_t;
 
 static List block_list = NULL;
 
-static int _marknodes(db2_block_info_t *block_ptr, int count);
+static void _block_list_del(void *object);
+static int  _in_slurm_partition(List slurm_nodes, List bg_nodes);
+static int  _list_match_all(void *object, void *key);
+static int  _make_nodelist(char *nodes, List nodelist);
+static void _marknodes(db2_block_info_t *block_ptr, int count);
+static void _nodelist_del(void *object);
 static void _print_header_part(void);
+static int  _print_rest(db2_block_info_t *block_ptr);
 static int  _print_text_part(partition_info_t *part_ptr,
 			     db2_block_info_t *db2_info_ptr);
-static void _block_list_del(void *object);
-static void _nodelist_del(void *object);
-static int _list_match_all(void *object, void *key);
-static int _in_slurm_partition(List slurm_nodes, List bg_nodes);
-static int _print_rest(db2_block_info_t *block_ptr);
-static int _make_nodelist(char *nodes, List nodelist);
 
-extern void get_slurm_part()
+extern void get_slurm_part(void)
 {
-	int error_code, i, recs, count = 0;
+	int error_code, i, j, recs, count = 0;
 	static partition_info_msg_t *part_info_ptr = NULL;
 	static partition_info_msg_t *new_part_ptr = NULL;
 	partition_info_t part;
@@ -86,10 +85,10 @@ extern void get_slurm_part()
 	bitstr_t *nodes_req = NULL;
 	static uint16_t last_flags = 0;
 
-	if(params.all_flag)
+	if (params.all_flag)
 		show_flags |= SHOW_ALL;
 	if (part_info_ptr) {
-		if(show_flags != last_flags)
+		if (show_flags != last_flags)
 			part_info_ptr->last_update = 0;
 		error_code = slurm_load_partitions(part_info_ptr->last_update,
 						   &new_part_ptr, show_flags);
@@ -107,7 +106,7 @@ extern void get_slurm_part()
 	last_flags = show_flags;
 	if (error_code) {
 		if (quiet_flag != 1) {
-			if(!params.commandline) {
+			if (!params.commandline) {
 				mvwprintw(text_win,
 					  main_ycord, 1,
 					  "slurm_load_partitions: %s",
@@ -129,37 +128,32 @@ extern void get_slurm_part()
 	else
 		recs = 0;
 	if (!params.commandline)
-		if((recs - text_line_cnt) < (text_win->_maxy-3))
+		if ((recs - text_line_cnt) < (text_win->_maxy - 3))
 			text_line_cnt--;
 
-	if(params.hl)
+	if (params.hl)
 		nodes_req = get_requested_node_bitmap();
 	for (i = 0; i < recs; i++) {
 		part = new_part_ptr->partition_array[i];
 
-		if(nodes_req) {
+		if (nodes_req) {
 			int overlap = 0;
 			bitstr_t *loc_bitmap = bit_alloc(bit_size(nodes_req));
 			inx2bitstr(loc_bitmap, part.node_inx);
 			overlap = bit_overlap(loc_bitmap, nodes_req);
 			FREE_NULL_BITMAP(loc_bitmap);
-			if(!overlap)
+			if (!overlap)
 				continue;
 		}
-		if (((params.cluster_flags & CLUSTER_FLAG_BG) == 0) &&
-		    (params.cluster_dims == 3)) {
-			set_grid_inx2(part.nodes, count);
-		} else {
-			int j = 0;
-			while (part.node_inx[j] >= 0) {
-				set_grid_inx(part.node_inx[j],
-					     part.node_inx[j + 1], count);
-				j += 2;
-			}
+		j = 0;
+		while (part.node_inx[j] >= 0) {
+			set_grid_inx(part.node_inx[j],
+				     part.node_inx[j + 1], count);
+			j += 2;
 		}
 
-		if(!params.commandline) {
-			if(i>=text_line_cnt) {
+		if (!params.commandline) {
+			if (i >= text_line_cnt) {
 				part.flags = (int) letters[count%62];
 				wattron(text_win,
 					COLOR_PAIR(colors[count%6]));
@@ -174,8 +168,8 @@ extern void get_slurm_part()
 		count++;
 
 	}
-	if(count==128)
-		count=0;
+	if (count == 128)
+		count = 0;
 	if (params.commandline && params.iterate)
 		printf("\n");
 
@@ -183,9 +177,9 @@ extern void get_slurm_part()
 	return;
 }
 
-extern void get_bg_part()
+extern void get_bg_part(void)
 {
-	int error_code, i, j, recs=0, count = 0, last_count = -1;
+	int error_code, i, recs=0, count = 0, last_count = -1;
 	static partition_info_msg_t *part_info_ptr = NULL;
 	static partition_info_msg_t *new_part_ptr = NULL;
 	static block_info_msg_t *bg_info_ptr = NULL;
@@ -198,7 +192,7 @@ extern void get_bg_part()
 	List nodelist = NULL;
 	bitstr_t *nodes_req = NULL;
 
-	if(!(params.cluster_flags & CLUSTER_FLAG_BG))
+	if (!(params.cluster_flags & CLUSTER_FLAG_BG))
 		return;
 
 	if (params.all_flag)
@@ -219,7 +213,7 @@ extern void get_bg_part()
 
 	if (error_code) {
 		if (quiet_flag != 1) {
-			if(!params.commandline) {
+			if (!params.commandline) {
 				mvwprintw(text_win,
 					  main_ycord, 1,
 					  "slurm_load_partitions: %s",
@@ -247,7 +241,7 @@ extern void get_bg_part()
 	}
 	if (error_code) {
 		if (quiet_flag != 1) {
-			if(!params.commandline) {
+			if (!params.commandline) {
 				mvwprintw(text_win,
 					  main_ycord, 1,
 					  "slurm_load_block: %s",
@@ -271,32 +265,31 @@ extern void get_bg_part()
 		}
 	}
 	if (!params.commandline)
-		if((new_bg_ptr->record_count - text_line_cnt)
+		if ((new_bg_ptr->record_count - text_line_cnt)
 		   < (text_win->_maxy-3))
 			text_line_cnt--;
-	if(params.hl)
+	if (params.hl)
 		nodes_req = get_requested_node_bitmap();
-	for (i=0; i<new_bg_ptr->record_count; i++) {
-		if(nodes_req) {
+	for (i = 0; i < new_bg_ptr->record_count; i++) {
+		if (nodes_req) {
 			int overlap = 0;
 			bitstr_t *loc_bitmap = bit_alloc(bit_size(nodes_req));
 			inx2bitstr(loc_bitmap,
-				   new_bg_ptr->block_array[i].bp_inx);
+				   new_bg_ptr->block_array[i].mp_inx);
 			overlap = bit_overlap(loc_bitmap, nodes_req);
 			FREE_NULL_BITMAP(loc_bitmap);
-			if(!overlap)
+			if (!overlap)
 				continue;
 		}
-		if(params.io_bit && new_bg_ptr->block_array[i].ionodes) {
+		if (params.io_bit && new_bg_ptr->block_array[i].ionode_str) {
 			int overlap = 0;
 			bitstr_t *loc_bitmap =
 				bit_alloc(bit_size(params.io_bit));
 			inx2bitstr(loc_bitmap,
 				   new_bg_ptr->block_array[i].ionode_inx);
-			overlap = bit_overlap(loc_bitmap,
-					      params.io_bit);
+			overlap = bit_overlap(loc_bitmap, params.io_bit);
 			FREE_NULL_BITMAP(loc_bitmap);
-			if(!overlap)
+			if (!overlap)
 				continue;
 		}
 
@@ -304,26 +297,29 @@ extern void get_bg_part()
 
 		block_ptr->bg_block_name
 			= xstrdup(new_bg_ptr->block_array[i].bg_block_id);
-		block_ptr->nodes = xstrdup(new_bg_ptr->block_array[i].nodes);
+		block_ptr->mp_str = xstrdup(new_bg_ptr->block_array[i].mp_str);
 		block_ptr->nodelist = list_create(_nodelist_del);
-		_make_nodelist(block_ptr->nodes,block_ptr->nodelist);
+		_make_nodelist(block_ptr->mp_str, block_ptr->nodelist);
 
 		block_ptr->bg_user_name
 			= xstrdup(new_bg_ptr->block_array[i].owner_name);
 		block_ptr->state = new_bg_ptr->block_array[i].state;
-		block_ptr->bg_conn_type	= new_bg_ptr->block_array[i].conn_type;
-		if(params.cluster_flags & CLUSTER_FLAG_BGL)
+
+		memcpy(block_ptr->bg_conn_type,
+		       new_bg_ptr->block_array[i].conn_type,
+		       sizeof(block_ptr->bg_conn_type));
+
+		if (params.cluster_flags & CLUSTER_FLAG_BGL)
 			block_ptr->bg_node_use =
 				new_bg_ptr->block_array[i].node_use;
 
-		block_ptr->ionodes
-			= xstrdup(new_bg_ptr->block_array[i].ionodes);
-		block_ptr->node_cnt = new_bg_ptr->block_array[i].node_cnt;
+		block_ptr->ionode_str
+			= xstrdup(new_bg_ptr->block_array[i].ionode_str);
+		block_ptr->cnode_cnt = new_bg_ptr->block_array[i].cnode_cnt;
 
 		itr = list_iterator_create(block_list);
-		while ((found_block = (db2_block_info_t*)list_next(itr))
-		       != NULL) {
-			if(!strcmp(block_ptr->nodes, found_block->nodes)) {
+		while ((found_block = (db2_block_info_t*)list_next(itr))) {
+			if (!strcmp(block_ptr->mp_str, found_block->mp_str)) {
 				block_ptr->letter_num =
 					found_block->letter_num;
 				break;
@@ -331,13 +327,13 @@ extern void get_bg_part()
 		}
 		list_iterator_destroy(itr);
 
-		if(!found_block) {
+		if (!found_block) {
 			last_count++;
 			_marknodes(block_ptr, last_count);
 		}
 		block_ptr->job_running =
 			new_bg_ptr->block_array[i].job_running;
-		if(block_ptr->bg_conn_type >= SELECT_SMALL)
+		if (block_ptr->bg_conn_type[0] >= SELECT_SMALL)
 			block_ptr->size = 0;
 
 		list_append(block_list, block_ptr);
@@ -352,19 +348,18 @@ extern void get_bg_part()
 		recs = 0;
 
 	for (i = 0; i < recs; i++) {
-		j = 0;
 		part = new_part_ptr->partition_array[i];
 
 		if (!part.nodes || (part.nodes[0] == '\0'))
 			continue;	/* empty partition */
 		nodelist = list_create(_nodelist_del);
-		_make_nodelist(part.nodes,nodelist);
+		_make_nodelist(part.nodes, nodelist);
 
 		if (block_list) {
 			itr = list_iterator_create(block_list);
 			while ((block_ptr = (db2_block_info_t*)
 				list_next(itr)) != NULL) {
-				if(_in_slurm_partition(nodelist,
+				if (_in_slurm_partition(nodelist,
 						       block_ptr->nodelist)) {
 					block_ptr->slurm_part_name
 						= xstrdup(part.name);
@@ -383,13 +378,12 @@ extern void get_bg_part()
 			if (params.commandline)
 				block_ptr->printed = 1;
 			else {
-				if(count>=text_line_cnt)
+				if (count>=text_line_cnt)
 					block_ptr->printed = 1;
 			}
 			_print_rest(block_ptr);
 			count++;
 		}
-
 		list_iterator_destroy(itr);
 	}
 
@@ -402,75 +396,50 @@ extern void get_bg_part()
 	return;
 }
 
-static int _marknodes(db2_block_info_t *block_ptr, int count)
+static void _marknodes(db2_block_info_t *block_ptr, int count)
 {
-	int j=0;
+	int i, j = 0;
 	int start[params.cluster_dims];
 	int end[params.cluster_dims];
-	int number = 0;
-	char *p = '\0';
+	char *nodes = block_ptr->mp_str;
 
 	block_ptr->letter_num = count;
-	while (block_ptr->nodes[j] != '\0') {
-		if ((block_ptr->nodes[j] == '['
-		     || block_ptr->nodes[j] == ',')
-		    && (block_ptr->nodes[j+8] == ']'
-			|| block_ptr->nodes[j+8] == ',')
-		    && (block_ptr->nodes[j+4] == 'x'
-			|| block_ptr->nodes[j+4] == '-')) {
-			j++;
-
-			number = xstrntol(block_ptr->nodes + j, &p,
-					  params.cluster_dims,
-					  params.cluster_base);
-
-			hostlist_parse_int_to_array(
-				number, start, params.cluster_dims,
-				params.cluster_base);
-			j += 4;
-			number = xstrntol(block_ptr->nodes + j, &p,
-					  params.cluster_dims,
-					  params.cluster_base);
-			hostlist_parse_int_to_array(
-				number, end, params.cluster_dims,
-				params.cluster_base);
-			j += 3;
-
-			if(block_ptr->state != RM_PARTITION_FREE)
+	while (nodes[j] != '\0') {
+		int mid = j   + params.cluster_dims + 1;
+		int fin = mid + params.cluster_dims + 1;
+		if (((nodes[j] == '[')   || (nodes[j] == ','))   &&
+		    ((nodes[mid] == 'x') || (nodes[mid] == '-')) &&
+		    ((nodes[fin] == ']') || (nodes[fin] == ','))) {
+			j++;	/* Skip leading '[' or ',' */
+			for (i = 0; i < params.cluster_dims; i++, j++)
+				start[i] = select_char2coord(nodes[j]);
+			j++;	/* Skip middle 'x' or '-' */
+			for (i = 0; i < params.cluster_dims; i++, j++)
+				end[i] = select_char2coord(nodes[j]);
+			if (block_ptr->state != BG_BLOCK_FREE) {
 				block_ptr->size += set_grid_bg(
 					start, end, count, 1);
-			else
+			} else {
 				block_ptr->size += set_grid_bg(
 					start, end, count, 0);
-			if(block_ptr->nodes[j] != ',')
+			}
+			if (nodes[j] != ',')
 				break;
-			j--;
-		} else if((block_ptr->nodes[j] >= '0'
-			   && block_ptr->nodes[j] <= '9')
-			  || (block_ptr->nodes[j] >= 'A'
-			      && block_ptr->nodes[j] <= 'Z')) {
-
-			number = xstrntol(block_ptr->nodes + j, &p,
-					  params.cluster_dims,
-					  params.cluster_base);
-			hostlist_parse_int_to_array(
-				number, start, params.cluster_dims,
-				params.cluster_base);
-			j+=3;
-			block_ptr->size += set_grid_bg(
-				start, start, count, 0);
-			if(block_ptr->nodes[j] != ',')
+		} else if (((nodes[j] >= '0') && (nodes[j] <= '9')) ||
+			   ((nodes[j] >= 'A') && (nodes[j] <= 'Z'))) {
+			for (i = 0; i < params.cluster_dims; i++, j++)
+				start[i] = select_char2coord(nodes[j]);
+			block_ptr->size += set_grid_bg(start, start, count, 1);
+			if (nodes[j] != ',')
 				break;
-			j--;
-		}
-		j++;
+		} else
+			j++;
 	}
-	return SLURM_SUCCESS;
 }
 
 static void _print_header_part(void)
 {
-	if(!params.commandline) {
+	if (!params.commandline) {
 		mvwprintw(text_win, main_ycord,
 			  main_xcord, "ID");
 		main_xcord += 4;
@@ -507,8 +476,8 @@ static void _print_header_part(void)
 			mvwprintw(text_win,
 				  main_ycord,
 				  main_xcord, "CONN");
-			main_xcord += 7;
-			if(params.cluster_flags & CLUSTER_FLAG_BGL) {
+			main_xcord += 8;
+			if (params.cluster_flags & CLUSTER_FLAG_BGL) {
 				mvwprintw(text_win,
 					  main_ycord,
 					  main_xcord, "NODE_USE");
@@ -519,7 +488,7 @@ static void _print_header_part(void)
 		mvwprintw(text_win, main_ycord,
 			  main_xcord, "NODES");
 		main_xcord += 7;
-		if(params.cluster_flags & CLUSTER_FLAG_BG)
+		if (params.cluster_flags & CLUSTER_FLAG_BG)
 			mvwprintw(text_win, main_ycord,
 				  main_xcord, "BP_LIST");
 		else
@@ -537,13 +506,13 @@ static void _print_header_part(void)
 			printf("STATE ");
 			printf("   JOBID ");
 			printf("    USER ");
-			printf(" CONN ");
-			if(params.cluster_flags & CLUSTER_FLAG_BGL)
+			printf("    CONN ");
+			if (params.cluster_flags & CLUSTER_FLAG_BGL)
 				printf(" NODE_USE ");
 		}
 
 		printf("NODES ");
-		if(params.cluster_flags & CLUSTER_FLAG_BG)
+		if (params.cluster_flags & CLUSTER_FLAG_BG)
 			printf("BP_LIST\n");
 		else
 			printf("NODELIST\n");
@@ -558,17 +527,17 @@ static int _print_text_part(partition_info_t *part_ptr,
 	int prefixlen;
 	int i = 0;
 	int width = 0;
-	char *nodes = NULL, time_buf[20];
+	char *nodes = NULL, time_buf[20], *conn_str = NULL;
 	char tmp_cnt[8];
 	char tmp_char[8];
 
-	if(params.cluster_flags & CLUSTER_FLAG_BG)
+	if (params.cluster_flags & CLUSTER_FLAG_BG)
 		convert_num_unit((float)part_ptr->total_nodes, tmp_cnt,
 				 sizeof(tmp_cnt), UNIT_NONE);
 	else
 		snprintf(tmp_cnt, sizeof(tmp_cnt), "%u", part_ptr->total_nodes);
 
-	if(!params.commandline) {
+	if (!params.commandline) {
 		mvwprintw(text_win,
 			  main_ycord,
 			  main_xcord, "%c",
@@ -632,7 +601,7 @@ static int _print_text_part(partition_info_t *part_ptr,
 						  db2_info_ptr->state));
 				main_xcord += 7;
 
-				if(db2_info_ptr->job_running > NO_JOB_RUNNING)
+				if (db2_info_ptr->job_running > NO_JOB_RUNNING)
 					snprintf(tmp_char, sizeof(tmp_char),
 						 "%d",
 						 db2_info_ptr->job_running);
@@ -652,14 +621,16 @@ static int _print_text_part(partition_info_t *part_ptr,
 					  db2_info_ptr->bg_user_name);
 				main_xcord += 9;
 
+				conn_str = conn_type_string_full(
+					db2_info_ptr->bg_conn_type);
 				mvwprintw(text_win,
 					  main_ycord,
-					  main_xcord, "%.5s",
-					  conn_type_string(
-						  db2_info_ptr->
-						  bg_conn_type));
-				main_xcord += 7;
-				if(params.cluster_flags & CLUSTER_FLAG_BGL) {
+					  main_xcord, "%.7s",
+					  conn_str);
+				xfree(conn_str);
+				main_xcord += 8;
+
+				if (params.cluster_flags & CLUSTER_FLAG_BGL) {
 					mvwprintw(text_win,
 						  main_ycord,
 						  main_xcord, "%.9s",
@@ -707,14 +678,14 @@ static int _print_text_part(partition_info_t *part_ptr,
 			nodes = part_ptr->allow_groups;
 		else
 			nodes = part_ptr->nodes;
-		i=0;
+		i = 0;
 		prefixlen = i;
 		while (nodes && nodes[i]) {
 			width = text_win->_maxx
 				- main_xcord;
 
-			if (!prefixlen && nodes[i] == '['
-			    && nodes[i - 1] == ',')
+			if (!prefixlen && (nodes[i] == '[') &&
+			    (nodes[i - 1] == ','))
 				prefixlen = i + 1;
 
 			if (nodes[i - 1] == ',' && (width - 12) <= 0) {
@@ -736,12 +707,12 @@ static int _print_text_part(partition_info_t *part_ptr,
 
 			i++;
 		}
-		if((params.display == BGPART) && db2_info_ptr
-		   && (db2_info_ptr->ionodes)) {
+		if ((params.display == BGPART) && db2_info_ptr &&
+		    (db2_info_ptr->ionode_str)) {
 			mvwprintw(text_win,
 				  main_ycord,
 				  main_xcord, "[%s]",
-				  db2_info_ptr->ionodes);
+				  db2_info_ptr->ionode_str);
 		}
 
 		main_xcord = 1;
@@ -785,7 +756,7 @@ static int _print_text_part(partition_info_t *part_ptr,
 				       bg_block_state_string(
 					       db2_info_ptr->state));
 
-				if(db2_info_ptr->job_running > NO_JOB_RUNNING)
+				if (db2_info_ptr->job_running > NO_JOB_RUNNING)
 					snprintf(tmp_char, sizeof(tmp_char),
 						 "%d",
 						 db2_info_ptr->job_running);
@@ -796,9 +767,12 @@ static int _print_text_part(partition_info_t *part_ptr,
 				printf("%8.8s ", tmp_char);
 				printf("%8.8s ", db2_info_ptr->bg_user_name);
 
-				printf("%5.5s ", conn_type_string(
-					       db2_info_ptr->bg_conn_type));
-				if(params.cluster_flags & CLUSTER_FLAG_BGL)
+				conn_str = conn_type_string_full(
+					db2_info_ptr->bg_conn_type);
+				printf("%8.8s ", conn_str);
+				xfree(conn_str);
+
+				if (params.cluster_flags & CLUSTER_FLAG_BGL)
 					printf("%9.9s ", node_use_string(
 						       db2_info_ptr->
 						       bg_node_use));
@@ -812,9 +786,9 @@ static int _print_text_part(partition_info_t *part_ptr,
 		else
 			nodes = part_ptr->nodes;
 
-		if((params.display == BGPART) && db2_info_ptr
-		   && (db2_info_ptr->ionodes)) {
-			printf("%s[%s]\n", nodes, db2_info_ptr->ionodes);
+		if ((params.display == BGPART) && db2_info_ptr &&
+		    (db2_info_ptr->ionode_str)) {
+			printf("%s[%s]\n", nodes, db2_info_ptr->ionode_str);
 		} else
 			printf("%s\n",nodes);
 	}
@@ -829,9 +803,9 @@ static void _block_list_del(void *object)
 		xfree(block_ptr->bg_user_name);
 		xfree(block_ptr->bg_block_name);
 		xfree(block_ptr->slurm_part_name);
-		xfree(block_ptr->nodes);
-		xfree(block_ptr->ionodes);
-		if(block_ptr->nodelist)
+		xfree(block_ptr->mp_str);
+		xfree(block_ptr->ionode_str);
+		if (block_ptr->nodelist)
 			list_destroy(block_ptr->nodelist);
 
 		xfree(block_ptr);
@@ -848,7 +822,6 @@ static void _nodelist_del(void *object)
 
 static int _list_match_all(void *object, void *key)
 {
-
 	return 1;
 }
 
@@ -858,7 +831,7 @@ static int _in_slurm_partition(List slurm_nodes, List bg_nodes)
 	ListIterator bg_itr;
 	int *coord = NULL;
 	int *slurm_coord = NULL;
-	int found = 0;
+	int found = 0, i;
 
 	bg_itr = list_iterator_create(bg_nodes);
 	slurm_itr = list_iterator_create(slurm_nodes);
@@ -866,21 +839,22 @@ static int _in_slurm_partition(List slurm_nodes, List bg_nodes)
 		list_iterator_reset(slurm_itr);
 		found = 0;
 		while ((slurm_coord = list_next(slurm_itr)) != NULL) {
-			if((coord[X] == slurm_coord[X])
-			   && (coord[Y] == slurm_coord[Y])
-			   && (coord[Z] == slurm_coord[Z])) {
-				found=1;
+			for (i = 0; i < params.cluster_dims; i++) {
+				if (coord[i] != slurm_coord[i])
+					break;
+			}
+			if (i >= params.cluster_dims) {
+				found = 1;
 				break;
 			}
 		}
-		if(!found) {
+		if (!found)
 			break;
-		}
 	}
 	list_iterator_destroy(slurm_itr);
 	list_iterator_destroy(bg_itr);
 
-	if(found)
+	if (found)
 		return 1;
 	else
 		return 0;
@@ -891,19 +865,19 @@ static int _print_rest(db2_block_info_t *block_ptr)
 {
 	partition_info_t part;
 
-	if(block_ptr->node_cnt == 0)
-		block_ptr->node_cnt = block_ptr->size;
-	part.total_nodes = block_ptr->node_cnt;
-	if(block_ptr->slurm_part_name)
+	if (block_ptr->cnode_cnt == 0)
+		block_ptr->cnode_cnt = block_ptr->size;
+	part.total_nodes = block_ptr->cnode_cnt;
+	if (block_ptr->slurm_part_name)
 		part.name = block_ptr->slurm_part_name;
 	else
 		part.name = "no part";
 
 	if (!block_ptr->printed)
 		return SLURM_SUCCESS;
-	part.allow_groups = block_ptr->nodes;
+	part.allow_groups = block_ptr->mp_str;
 	part.flags = (int) letters[block_ptr->letter_num%62];
-	if(!params.commandline) {
+	if (!params.commandline) {
 		wattron(text_win,
 			COLOR_PAIR(colors[block_ptr->letter_num%6]));
 		_print_text_part(&part, block_ptr);
@@ -915,85 +889,90 @@ static int _print_rest(db2_block_info_t *block_ptr)
 	return SLURM_SUCCESS;
 }
 
-static int _addto_nodelist(List nodelist, int *start, int *end)
+static int *_build_coord(int *current)
+{
+	int i;
+	int *coord = NULL;
+
+	coord = xmalloc(sizeof(int) * params.cluster_dims);
+	for (i = 0; i < params.cluster_dims; i++)
+		coord[i] = current[i];
+	return coord;
+}
+
+/* increment an array, return false if can't be incremented (reached limts) */
+static bool _incr_coord(int *start, int *end, int *current)
+{
+	int i;
+
+	for (i = 0; i < params.cluster_dims; i++) {
+		current[i]++;
+		if (current[i] <= end[i])
+			return true;
+		current[i] = start[i];
+	}
+	return false;
+}
+
+static void _addto_nodelist(List nodelist, int *start, int *end)
 {
 	int *coord = NULL;
-	int x,y,z;
-	if(end[X] >= DIM_SIZE[X]
-	   || end[Y] >= DIM_SIZE[Y]
-	   || end[Z] >= DIM_SIZE[Z]) {
+	int i;
+
+	coord = xmalloc(sizeof(int) * params.cluster_dims);
+	for (i = 0; i < params.cluster_dims; i++) {
+		xassert(start[i] >= 0);
+		coord[i] = start[i];
+		if (end[i] < dim_size[i])
+			continue;
 		fatal("It appears the slurm.conf file has changed since "
 		      "the last restart.\nThings are in an incompatible "
 		      "state, please restart the slurmctld.");
 	}
 
-	assert(start[X] >= 0);
-	assert(start[Y] >= 0);
-	assert(start[X] >= 0);
+	do {
+		list_append(nodelist, _build_coord(coord));
+	} while (_incr_coord(start, end, coord));
 
-	for (x = start[X]; x <= end[X]; x++) {
-		for (y = start[Y]; y <= end[Y]; y++) {
-			for (z = start[Z]; z <= end[Z]; z++) {
-				coord = xmalloc(sizeof(int)*3);
-				coord[X] = x;
-				coord[Y] = y;
-				coord[Z] = z;
-				list_append(nodelist, coord);
-			}
-		}
-	}
-	return 1;
+	xfree(coord);
 }
 
 static int _make_nodelist(char *nodes, List nodelist)
 {
-	int j = 0;
-	int number;
+	int i, j = 0;
 	int start[params.cluster_dims];
 	int end[params.cluster_dims];
-	char *p = '\0';
 
-	if(!nodelist)
+	if (!nodelist)
 		nodelist = list_create(_nodelist_del);
+
 	while (nodes[j] != '\0') {
-		if ((nodes[j] == '['
-		     || nodes[j] == ',')
-		    && (nodes[j+8] == ']'
-			|| nodes[j+8] == ',')
-		    && (nodes[j+4] == 'x'
-			|| nodes[j+4] == '-')) {
-			j++;
-			number = xstrntol(nodes + j, &p, params.cluster_dims,
-					  params.cluster_base);
-			hostlist_parse_int_to_array(
-				number, start, params.cluster_dims,
-				params.cluster_base);
-			j += 4;
-			number = xstrntol(nodes + j, &p, params.cluster_dims,
-					  params.cluster_base);
-			hostlist_parse_int_to_array(
-				number, end, params.cluster_dims,
-				params.cluster_base);
-			j += 3;
+		int mid = j   + params.cluster_dims + 1;
+		int fin = mid + params.cluster_dims + 1;
+		if (((nodes[j] == '[')   || (nodes[j] == ','))   &&
+		    ((nodes[mid] == 'x') || (nodes[mid] == '-')) &&
+		    ((nodes[fin] == ']') || (nodes[fin] == ','))) {
+			j++;	/* Skip leading '[' or ',' */
+			for (i = 0; i < params.cluster_dims; i++, j++)
+				start[i] = select_char2coord(nodes[j]);
+			j++;	/* Skip middle 'x' or '-' */
+			for (i = 0; i < params.cluster_dims; i++, j++)
+				end[i] = select_char2coord(nodes[j]);
 			_addto_nodelist(nodelist, start, end);
-			if(nodes[j] != ',')
+			if (nodes[j] != ',')
 				break;
 			j--;
-		} else if((nodes[j] >= '0' && nodes[j] <= '9')
-			  || (nodes[j] >= 'A' && nodes[j] <= 'Z')) {
-
-			number = xstrntol(nodes + j, &p, params.cluster_dims,
-					  params.cluster_base);
-			hostlist_parse_int_to_array(
-				number, start, params.cluster_dims,
-				params.cluster_base);
-			j+=3;
+		} else if (((nodes[j] >= '0') && (nodes[j] <= '9')) ||
+			   ((nodes[j] >= 'A') && (nodes[j] <= 'Z'))) {
+			for (i = 0; i < params.cluster_dims; i++, j++)
+				start[i] = select_char2coord(nodes[j]);
 			_addto_nodelist(nodelist, start, start);
-			if(nodes[j] != ',')
+			if (nodes[j] != ',')
 				break;
 			j--;
 		}
 		j++;
 	}
+
 	return 1;
 }
