@@ -121,9 +121,8 @@ int main(int argc, char *argv[])
 		}
 	}
 
-#ifdef HAVE_BG
-	bg_configure_ba_init(new_node_ptr, 0);
-#endif
+	select_g_ba_init(new_node_ptr, 0);
+
 	if (dim_size == NULL) {
 		dim_size = get_cluster_dims(new_node_ptr);
 		if ((dim_size == NULL) || (dim_size[0] < 1))
@@ -211,6 +210,7 @@ redraw:
 			clear_window(grid_win);
 			move(0, 0);
 
+			update_grid(new_node_ptr);
 			main_xcord = 1;
 			main_ycord = 1;
 		}
