@@ -7,7 +7,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <https://computing.llnl.gov/linux/slurm/>.
+ *  For details, see <http://www.schedmd.com/slurmdocs/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -76,6 +76,22 @@ static void  _parse_token( char *token, char *field, int *field_size,
 static void  _print_options( void );
 static void  _usage( void );
 
+static void _opt_env(void)
+{
+	char *env_val;
+
+	if ((env_val = getenv("SLURM_CLUSTERS"))) {
+		if (!(params.clusters = slurmdb_get_info_cluster(env_val))) {
+			error("'%s' can't be reached now, "
+			      "or it is an invalid entry for "
+			      "SLURM_CLUSTERS.  Use 'sacctmgr --list "
+			      "cluster' to see available clusters.",
+			      env_val);
+			exit(1);
+		}
+	}
+}
+
 /*
  * parse_command_line
  */
@@ -102,6 +118,9 @@ parse_command_line( int argc, char* argv[] )
 		{NULL,         0,                 0, 0}
 	};
 
+	/* get defaults from environment */
+	_opt_env();
+
 	while((opt_char = getopt_long(argc, argv, "hj::lM:no:u:vVw",
 				      long_options, &option_index)) != -1) {
 		switch (opt_char) {
@@ -127,11 +146,13 @@ parse_command_line( int argc, char* argv[] )
 				list_destroy(params.clusters);
 			if(!(params.clusters =
 			     slurmdb_get_info_cluster(optarg))) {
-				error("'%s' invalid entry for --cluster",
+				error("'%s' can't be reached now, "
+				      "or it is an invalid entry for "
+				      "--cluster.  Use 'sacctmgr --list "
+				      "cluster' to see available clusters.",
 				      optarg);
 				exit(1);
 			}
-			working_cluster_rec = list_peek(params.clusters);
 			break;
 		case (int) 'n':
 			params.normalized = true;
@@ -175,8 +196,15 @@ parse_command_line( int argc, char* argv[] )
 		}
 	}
 
-	if ( params.verbose )
+	if (params.verbose)
 		_print_options();
+	if (params.clusters) {
+		if (list_count(params.clusters) > 1) {
+			fatal("Only one cluster can be used at a time with "
+			      "sprio");
+		}
+		working_cluster_rec = list_peek(params.clusters);
+	}
 }
 
 /*
