@@ -9,7 +9,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <https://computing.llnl.gov/linux/slurm/>.
+ *  For details, see <http://www.schedmd.com/slurmdocs/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -375,7 +375,6 @@ extern void create_config_popup(GtkAction *action, gpointer user_data)
 		GTK_STOCK_CLOSE,
 		GTK_RESPONSE_OK,
 		NULL);
-	int error_code;
 	GtkTreeStore *treestore =
 		_local_create_treestore_2cols(popup, 600, 400);
 	static slurm_ctl_conf_info_msg_t  *slurm_ctl_conf_ptr = NULL;
@@ -385,7 +384,7 @@ extern void create_config_popup(GtkAction *action, gpointer user_data)
 	g_signal_connect(G_OBJECT(popup), "response",
 			 G_CALLBACK(_delete_popup), NULL);
 
-	error_code = get_new_info_config(&slurm_ctl_conf_ptr);
+	(void) get_new_info_config(&slurm_ctl_conf_ptr);
 	_layout_conf_ctl(treestore, slurm_ctl_conf_ptr);
 
 	gtk_widget_show_all(popup);
@@ -483,6 +482,164 @@ extern void create_daemon_popup(GtkAction *action, gpointer user_data)
 	return;
 }
 
+extern void create_create_popup(GtkAction *action, gpointer user_data)
+{
+	GtkWidget *popup = gtk_dialog_new_with_buttons(
+		"Create",
+		GTK_WINDOW(user_data),
+		GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+		NULL);
+	int i, response = 0;
+	GtkWidget *label = NULL;
+	GtkWidget *entry = NULL;
+	GtkTreeModel *model = NULL;
+	GtkTreeIter iter;
+	const gchar *name = gtk_action_get_name(action);
+	sview_search_info_t sview_search_info;
+	job_desc_msg_t *job_msg = NULL;
+	submit_response_msg_t *slurm_alloc_msg = NULL;
+	update_part_msg_t *part_msg = NULL;
+	resv_desc_msg_t *resv_msg = NULL;
+	char *res_name, *temp;
+
+	sview_search_info.gchar_data = NULL;
+	sview_search_info.int_data = NO_VAL;
+	sview_search_info.int_data2 = NO_VAL;
+
+	label = gtk_dialog_add_button(GTK_DIALOG(popup),
+				      GTK_STOCK_OK, GTK_RESPONSE_OK);
+	gtk_window_set_default(GTK_WINDOW(popup), label);
+	gtk_dialog_add_button(GTK_DIALOG(popup),
+			      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
+	gtk_window_set_default_size(GTK_WINDOW(popup), 400, 600);
+
+	if (!strcmp(name, "batch_job")) {
+		sview_search_info.search_type = CREATE_BATCH_JOB;
+		entry = create_entry();
+		label = gtk_label_new(
+			"Batch job submission specifications\n\n"
+			"Specify size (task and/or node count) plus the\n"
+			"script. All other fields are optional.\n\n"
+			"More fields will be made available later.");
+		job_msg = xmalloc(sizeof(job_desc_msg_t));
+		slurm_init_job_desc_msg(job_msg);
+		job_msg->group_id = getuid();
+		job_msg->user_id  = getgid();
+		job_msg->work_dir = xmalloc(1024);
+		if (!getcwd(job_msg->work_dir, 1024))
+			goto end_it;
+		entry = create_job_entry(job_msg, model, &iter);
+	} else if (!strcmp(name, "partition")) {
+		sview_search_info.search_type = CREATE_PARTITION;
+		entry = create_entry();
+		label = gtk_label_new(
+			"Partition creation specifications\n\n"
+			"Specify Name. All other fields are optional.");
+		part_msg = xmalloc(sizeof(update_part_msg_t));
+		slurm_init_part_desc_msg(part_msg);
+		entry = create_part_entry(part_msg, model, &iter);
+	} else if (!strcmp(name, "reservation")) {
+		sview_search_info.search_type = CREATE_RESERVATION;
+		label = gtk_label_new(
+			"Reservation creation specifications\n\n"
+			"Specify Time_Start and either Duration or Time_End.\n"
+#ifdef HAVE_BG
+			"Specify either Node_Count or BP_List.\n"
+#else
+			"Specify either Node_Count or Node_List.\n"
+#endif
+			"Specify either Accounts or Users.\n\n"
+			"Supported Flags include: Maintenance, Overlap,\n"
+			"Ignore_Jobs, Daily and Weekly.\n"
+			"All other fields are optional.");
+		resv_msg = xmalloc(sizeof(resv_desc_msg_t));
+		slurm_init_resv_desc_msg(resv_msg);
+		entry = create_resv_entry(resv_msg, model, &iter);
+	} else {
+		sview_search_info.search_type = 0;
+		goto end_it;
+	}
+
+	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(popup)->vbox),
+			   label, FALSE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(popup)->vbox),
+			   entry, TRUE, TRUE, 0);
+
+	gtk_widget_show_all(popup);
+	response = gtk_dialog_run (GTK_DIALOG(popup));
+
+	if (response == GTK_RESPONSE_OK) {
+		if (!sview_search_info.search_type)
+			goto end_it;
+
+		switch(sview_search_info.search_type) {
+		case CREATE_BATCH_JOB:
+			response = slurm_submit_batch_job(job_msg,
+							  &slurm_alloc_msg);
+			if (response == SLURM_SUCCESS) {
+				temp = g_strdup_printf(
+					"Job %u submitted",
+					slurm_alloc_msg->job_id);
+			} else {
+				temp = g_strdup_printf(
+					"Problem submitting job: %s",
+					slurm_strerror(slurm_get_errno()));
+			}
+			display_edit_note(temp);
+			g_free(temp);
+			break;
+		case CREATE_PARTITION:
+			response = slurm_create_partition(part_msg);
+			if (response == SLURM_SUCCESS) {
+				temp = g_strdup_printf("Partition %s created",
+						       part_msg->name);
+			} else {
+				temp = g_strdup_printf(
+					"Problem creating partition: %s",
+					slurm_strerror(slurm_get_errno()));
+			}
+			display_edit_note(temp);
+			g_free(temp);
+			break;
+		case CREATE_RESERVATION:
+			res_name = slurm_create_reservation(resv_msg);
+			if (res_name) {
+				temp = g_strdup_printf(
+					"Reservation %s created",
+					res_name);
+				free(res_name);
+			} else {
+				temp = g_strdup_printf(
+					"Problem creating reservation: %s",
+					slurm_strerror(slurm_get_errno()));
+			}
+			display_edit_note(temp);
+			g_free(temp);
+			break;
+		default:
+			break;
+		}
+	}
+
+end_it:
+	gtk_widget_destroy(popup);
+	if (slurm_alloc_msg)
+		slurm_free_submit_response_response_msg(slurm_alloc_msg);
+	if (job_msg) {
+		for (i = 0; i < job_msg->argc; i++)
+			xfree(job_msg->argv[i]);
+		xfree(job_msg->argv);
+		xfree(job_msg->name);
+		xfree(job_msg->script);
+		xfree(job_msg->work_dir);
+		xfree(job_msg);
+	}
+	xfree(part_msg);
+	if (resv_msg)
+		slurm_free_resv_desc_msg(resv_msg);
+	return;
+}
+
 extern void create_search_popup(GtkAction *action, gpointer user_data)
 {
 	GtkWidget *popup = gtk_dialog_new_with_buttons(
@@ -528,6 +685,7 @@ extern void create_search_popup(GtkAction *action, gpointer user_data)
 			{G_TYPE_NONE, JOB_FAILED, "Failed", TRUE, -1},
 			{G_TYPE_NONE, JOB_TIMEOUT, "Timeout", TRUE, -1},
 			{G_TYPE_NONE, JOB_NODE_FAIL, "Node Failure", TRUE, -1},
+			{G_TYPE_NONE, JOB_PREEMPTED, "Preempted", TRUE, -1},
 			{G_TYPE_NONE, -1, NULL, FALSE, -1}
 		};
 
@@ -590,18 +748,17 @@ extern void create_search_popup(GtkAction *action, gpointer user_data)
 		sview_search_info.search_type = SEARCH_BLOCK_SIZE;
 		entry = create_entry();
 		label = gtk_label_new("Which block size?");
-	} else if ((cluster_flags & CLUSTER_FLAG_BG)
-		   && !strcmp(name, "bg_block_state")) {
+	} else if (!strcmp(name, "bg_block_state")) {
 		display_data_t pulldown_display_data[] = {
-			{G_TYPE_NONE, RM_PARTITION_FREE, "Free", TRUE, -1},
-			{G_TYPE_NONE, RM_PARTITION_CONFIGURING, "Configuring",
-			 TRUE, -1},
-			{G_TYPE_NONE, RM_PARTITION_READY, "Ready", TRUE, -1},
-			{G_TYPE_NONE, RM_PARTITION_BUSY, NULL, TRUE, -1},
-			{G_TYPE_NONE, RM_PARTITION_REBOOTING, NULL, TRUE, -1},
-			{G_TYPE_NONE, RM_PARTITION_DEALLOCATING,
-			 "Deallocating", TRUE, -1},
-			{G_TYPE_NONE, RM_PARTITION_ERROR, "Error", TRUE, -1},
+			{G_TYPE_NONE, BG_BLOCK_NAV, "Nav", TRUE, -1},
+			{G_TYPE_NONE, BG_BLOCK_FREE, "Free", TRUE, -1},
+			{G_TYPE_NONE, BG_BLOCK_BUSY, NULL, TRUE, -1},
+			{G_TYPE_NONE, BG_BLOCK_BOOTING, "Booting", TRUE, -1},
+			{G_TYPE_NONE, BG_BLOCK_REBOOTING, NULL, TRUE, -1},
+			{G_TYPE_NONE, BG_BLOCK_INITED, "Inited", TRUE, -1},
+			{G_TYPE_NONE, BG_BLOCK_ALLOCATED, NULL, TRUE, -1},
+			{G_TYPE_NONE, BG_BLOCK_TERM, "Terminating", TRUE, -1},
+			{G_TYPE_NONE, BG_BLOCK_ERROR_FLAG, "Error", TRUE, -1},
 			{G_TYPE_NONE, -1, NULL, FALSE, -1}
 		};
 		display_data_t *display_data = pulldown_display_data;
@@ -610,14 +767,20 @@ extern void create_search_popup(GtkAction *action, gpointer user_data)
 				break;
 			if (cluster_flags & CLUSTER_FLAG_BGL) {
 				switch(display_data->id) {
-				case RM_PARTITION_BUSY:
+				case BG_BLOCK_BUSY:
 					display_data->name = "Busy";
 					break;
 				}
+			} else if (cluster_flags & CLUSTER_FLAG_BGP){
+				switch(display_data->id) {
+				case BG_BLOCK_REBOOTING:
+					display_data->name = "Rebooting";
+					break;
+				}
 			} else {
 				switch(display_data->id) {
-				case RM_PARTITION_REBOOTING:
-					display_data->name = "Rebooting";
+				case BG_BLOCK_ALLOCATED:
+					display_data->name = "Allocated";
 					break;
 				}
 			}
@@ -887,7 +1050,6 @@ extern void about_popup(GtkAction *action, gpointer user_data)
 		GTK_WINDOW(user_data),
 		GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 		NULL);
-	int response = 0;
 	char *version = NULL;
 
 	version = xstrdup_printf("SLURM Version: %s", SLURM_VERSION_STRING);
@@ -911,7 +1073,57 @@ extern void about_popup(GtkAction *action, gpointer user_data)
 	gtk_table_attach_defaults(GTK_TABLE(table), label, 0, 1, 0, 1);
 
 	gtk_widget_show_all(popup);
-	response = gtk_dialog_run (GTK_DIALOG(popup));
+	(void) gtk_dialog_run (GTK_DIALOG(popup));
+
+	gtk_widget_destroy(popup);
+
+	return;
+}
+
+extern void usage_popup(GtkAction *action, gpointer user_data)
+{
+	GtkWidget *table = gtk_table_new(1, 1, FALSE);
+	GtkWidget *label = NULL;
+
+	GtkWidget *popup = gtk_dialog_new_with_buttons(
+		"Usage",
+		GTK_WINDOW(user_data),
+		GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+		NULL);
+	char *help_msg =
+		"sview can be used to view and modify many of SLURM's\n"
+		"records.\n\n"
+		"Tabs are used to select the data type to work with.\n"
+		"Right click on the tab to select it. Left click on\n"
+		"the tab to control the fields of the table to be\n"
+		"displayed. Those fields can then be re-ordered or used\n"
+		"for sorting the records.\n\n"
+		"Left click on a record to see the compute nodes\n"
+		"associated with it. Right click on a record to modify\n"
+		"it. The colored boxes represent compute nodes associated\n"
+		"with each job, partition, etc. and may also selected\n"
+		"with right and left buttons.\n\n"
+		"Select 'Option' then 'Admin mode' to enable editing\n"
+		"of the records.\n";
+
+	label = gtk_dialog_add_button(GTK_DIALOG(popup),
+				      GTK_STOCK_OK, GTK_RESPONSE_OK);
+
+	gtk_window_set_default(GTK_WINDOW(popup), label);
+
+	gtk_window_set_default_size(GTK_WINDOW(popup), 200, 50);
+
+	label = gtk_label_new(help_msg);
+
+	gtk_container_set_border_width(GTK_CONTAINER(table), 10);
+
+	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(popup)->vbox),
+			   table, FALSE, FALSE, 0);
+
+	gtk_table_attach_defaults(GTK_TABLE(table), label, 0, 1, 0, 1);
+
+	gtk_widget_show_all(popup);
+	(void) gtk_dialog_run (GTK_DIALOG(popup));
 
 	gtk_widget_destroy(popup);
 
